<p align="center" >
<img src=".github/branding/dragon.svg" alt="Logo" width=200px> 
</p>
<p align="center">
  <strong>
  dragon is an expansible build system built for speed and ease of use.
  </strong>
  <br>
  <br>
  <a href="https://github.com/dragonbuild/dragon/actions/workflows/tests.yml">
    <image src="https://github.com/dragonbuild/dragon/actions/workflows/tests.yml/badge.svg">
  </a>
  <a href="https://dragon.krit.me">
    <image src="https://readthedocs.org/projects/dragon/badge/?version=latest">
  </a>
  <a href="https://pypi.org/project/dragon/">
    <image src="https://pypip.in/v/dragon/badge.svg">
  </a>
  <br>
  <br>
  <a href="https://dragon.krit.me">
    <strong>Documentation</strong>
  </a> | 
  <a href="https://dragon.krit.me/en/latest/quickstart.html">
    <strong>Getting Started</strong>
  </a> | 
  <a href="https://github.com/dragonbuild/example ">
    <strong>Example Project</strong>
  </a> | 
  <a href="https://github.com/dragonbuild/build ">
    <strong>Github Actions Integration</strong>
  </a>
</p>

# Installing dragon

In your terminal:

`pip3 install dragon`
  
## Updating
    
Version 1.6.0 and later:
    
```sh
dragon update
```
    
Version 1.5.1 and older:
  
```sh
rm -rf ~/.dragon
pip3 install --force-reinstall dragon
```

---

    
# Helpful links

[sbingner's arm64e toolchain](https://github.com/sbingner/llvm-project/releases/latest)
